/// @file    plugins/memcache/MemcacheFunctions.h
/// @brief   function array for the memcached plugin.
/// @author  Martin Philipp Hellmich <mhellmic@cern.ch>
#ifndef MEMCACHE_FUNCTIONS_H
#define MEMCACHE_FUNCTIONS_H

#define NUM_CATALOG_API_FUNCTIONS 84

namespace dmlite {

  enum {
    /// Catalog Functions
    // direct functions
    CHANGEDIR = 0,
    GETWORKINGDIR,
    EXTENDEDSTAT,
    EXTENDEDSTATBYRFN,
    ACCESS,
    ACCESSREPLICA,
    ADDREPLICA,
    DELETEREPLICA,
    GETREPLICAS,
    SYMLINK,
    READLINK,
    UNLINK,
    CREATE,
    UMASK,
    SETMODE,
    SETOWNER,
    SETSIZE,
    SETCHECKSUM,
    GETCHECKSUM,
    SETACL,
    UTIME,
    GETCOMMENT,
    SETCOMMENT,
    SETGUID,
    UPDATEEXTENDEDATTRIBUTES,
    OPENDIR,
    CLOSEDIR,
    READDIR,
    READDIRX,
    MAKEDIR,
    RENAME,
    REMOVEDIR,
    GETREPLICABYRFN,
    UPDATEREPLICA,
    // delegate functions
    CHANGEDIR_DELEGATE,
    GETWORKINGDIR_DELEGATE,
    EXTENDEDSTAT_DELEGATE,
    EXTENDEDSTATBYRFN_DELEGATE,
    ACCESS_DELEGATE,
    ACCESSREPLICA_DELEGATE,
    ADDREPLICA_DELEGATE,
    DELETEREPLICA_DELEGATE,
    GETREPLICAS_DELEGATE,
    SYMLINK_DELEGATE,
    READLINK_DELEGATE,
    UNLINK_DELEGATE,
    CREATE_DELEGATE,
    UMASK_DELEGATE,
    SETMODE_DELEGATE,
    SETOWNER_DELEGATE,
    SETSIZE_DELEGATE,
    SETCHECKSUM_DELEGATE,
    GETCHECKSUM_DELEGATE,
    SETACL_DELEGATE,
    UTIME_DELEGATE,
    GETCOMMENT_DELEGATE,
    SETCOMMENT_DELEGATE,
    SETGUID_DELEGATE,
    UPDATEEXTENDEDATTRIBUTES_DELEGATE,
    OPENDIR_DELEGATE,
    CLOSEDIR_DELEGATE,
    READDIR_DELEGATE,
    READDIRX_DELEGATE,
    MAKEDIR_DELEGATE,
    RENAME_DELEGATE,
    REMOVEDIR_DELEGATE,
    GETREPLICABYRFN_DELEGATE,
    UPDATEREPLICA_DELEGATE,
    /// PoolManager Functions
    // direct functions
    GETPOOLS,
    GETPOOL,
    NEWPOOL,
    UPDATEPOOL,
    DELETEPOOL,
    WHERETOREAD,
    WHERETOWRITE,
    CANCELWRITE,
    // delegate functions
    GETPOOLS_DELEGATE,
    GETPOOL_DELEGATE,
    NEWPOOL_DELEGATE,
    UPDATEPOOL_DELEGATE,
    DELETEPOOL_DELEGATE,
    WHERETOREAD_DELEGATE,
    WHERETOWRITE_DELEGATE,
    CANCELWRITE_DELEGATE
  };

  static const char* const catalog_func_names[] = {
    /// Catalog Functions
    // direct functions
    "changeDir",
    "getWorkingDir",
    "extendedStat",
    "extendedStatByRFN",
    "access",
    "accessReplica",
    "addReplica",
    "deleteReplica",
    "getReplicas",
    "symlink",
    "readLink",
    "unlink",
    "create",
    "umask",
    "setMode",
    "setOwner",
    "setSize",
    "setChecksum",
    "getChecksum",
    "setAcl",
    "utime",
    "getComment",
    "setComment",
    "setGuid",
    "updateExtendedAttributes",
    "openDir",
    "closeDir",
    "readDir",
    "readDirx",
    "makeDir",
    "rename",
    "removeDir",
    "getReplicaByRFN",
    "updateReplica",
    // "delegate" functions
    "changeDir_delegate",
    "getWorkingDir_delegate",
    "extendedStat_delegate",
    "extendedStatByRFN_delegate",
    "access_delegate",
    "accessReplica_delegate",
    "addReplica_delegate",
    "deleteReplica_delegate",
    "getReplicas_delegate",
    "symlink_delegate",
    "readLink_delegate",
    "unlink_delegate",
    "create_delegate",
    "umask_delegate",
    "setMode_delegate",
    "setOwner_delegate",
    "setSize_delegate",
    "setChecksum_delegate",
    "getChecksum_delegate",
    "setAcl_delegate",
    "utime_delegate",
    "getComment_delegate",
    "setComment_delegate",
    "setGuid_delegate",
    "updateExtendedAttributes_delegate",
    "openDir_delegate",
    "closeDir_delegate",
    "readDir_delegate",
    "readDirx_delegate",
    "makeDir_delegate",
    "rename_delegate",
    "removeDir_delegate",
    "getReplicaByRFN_delegate",
    "updateReplica_delegate"
    /// PoolManager Functions
    // direct functions
    "getPools",
    "getPool",
    "newPool",
    "updatePool",
    "deletePool",
    "whereToRead",
    "whereToWrite",
    "cancelWrite",
    // delegate functions
    "getPools_delegate",
    "getPool_delegate",
    "newPool_delegate",
    "updatePool_delegate",
    "deletePool_delegate",
    "whereToRead_delegate",
    "whereToWrite_delegate",
    "cancelWrite_delegate"
  };
}

#endif // MEMCACHE_FUNCTIONS_H
